@@ -23,9 +23,9 @@ import numpy as np
 # this needs to be before any modules that import protobuf
 os.environ["PROTOCOL_BUFFERS_PYTHON_IMPLEMENTATION"] = "python"
 
+import tritonclient.grpc.model_config_pb2 as model_config  # noqa
 from google.protobuf import text_format  # noqa
 
-import merlin.systems.triton.model_config_pb2 as model_config  # noqa
 from merlin.core.dispatch import is_string_dtype  # noqa
 from merlin.dag import ColumnSelector  # noqa
 from merlin.schema import Tags  # noqa
